Connections

Struct Connections 

pub struct Connections {
Show 27 fields pub tombstone: Option<i32>, pub status: Option<String>, pub previous_status: Option<String>, pub version: Option<i32>, pub created_date: Option<String>, pub created_time: Option<String>, pub updated_date: Option<String>, pub updated_time: Option<String>, pub organization_id: Option<String>, pub created_by: Option<String>, pub updated_by: Option<String>, pub deleted_by: Option<String>, pub requested_by: Option<String>, pub tags: Vec<String>, pub id: String, pub timestamp: String, pub interface_name: Option<String>, pub hypertable_timestamp: Option<String>, pub total_packet: Option<i32>, pub total_byte: Option<i32>, pub device_id: Option<String>, pub protocol: Option<String>, pub source_ip: Option<String>, pub destination_ip: Option<String>, pub remote_ip: Option<String>, pub source_port: Option<i32>, pub destination_port: Option<i32>,
}
Connections entity definition

Fields

tombstone: Option<i32>status: Option<String>previous_status: Option<String>version: Option<i32>created_date: Option<String>created_time: Option<String>updated_date: Option<String>updated_time: Option<String>organization_id: Option<String>created_by: Option<String>updated_by: Option<String>deleted_by: Option<String>requested_by: Option<String>tags: Vec<String>id: Stringtimestamp: Stringinterface_name: Option<String>hypertable_timestamp: Option<String>total_packet: Option<i32>total_byte: Option<i32>device_id: Option<String>protocol: Option<String>source_ip: Option<String>destination_ip: Option<String>remote_ip: Option<String>source_port: Option<i32>destination_port: Option<i32>

Implementations

Source

impl Connections

pub fn tombstone(&self) -> i32

Returns the value of tombstone, or the default value if tombstone is unset.

pub fn status(&self) -> &str

Returns the value of status, or the default value if status is unset.

pub fn previous_status(&self) -> &str

Returns the value of previous_status, or the default value if previous_status is unset.

pub fn version(&self) -> i32

Returns the value of version, or the default value if version is unset.

pub fn created_date(&self) -> &str

Returns the value of created_date, or the default value if created_date is unset.

pub fn created_time(&self) -> &str

Returns the value of created_time, or the default value if created_time is unset.

pub fn updated_date(&self) -> &str

Returns the value of updated_date, or the default value if updated_date is unset.

pub fn updated_time(&self) -> &str

Returns the value of updated_time, or the default value if updated_time is unset.

pub fn organization_id(&self) -> &str

Returns the value of organization_id, or the default value if organization_id is unset.

pub fn created_by(&self) -> &str

Returns the value of created_by, or the default value if created_by is unset.

pub fn updated_by(&self) -> &str

Returns the value of updated_by, or the default value if updated_by is unset.

pub fn deleted_by(&self) -> &str

Returns the value of deleted_by, or the default value if deleted_by is unset.

pub fn requested_by(&self) -> &str

Returns the value of requested_by, or the default value if requested_by is unset.

pub fn interface_name(&self) -> &str

Returns the value of interface_name, or the default value if interface_name is unset.

pub fn hypertable_timestamp(&self) -> &str

Returns the value of hypertable_timestamp, or the default value if hypertable_timestamp is unset.

pub fn total_packet(&self) -> i32

Returns the value of total_packet, or the default value if total_packet is unset.

pub fn total_byte(&self) -> i32

Returns the value of total_byte, or the default value if total_byte is unset.

pub fn device_id(&self) -> &str

Returns the value of device_id, or the default value if device_id is unset.

pub fn protocol(&self) -> &str

Returns the value of protocol, or the default value if protocol is unset.

pub fn source_ip(&self) -> &str

Returns the value of source_ip, or the default value if source_ip is unset.

pub fn destination_ip(&self) -> &str

Returns the value of destination_ip, or the default value if destination_ip is unset.

pub fn remote_ip(&self) -> &str

Returns the value of remote_ip, or the default value if remote_ip is unset.

pub fn source_port(&self) -> i32

Returns the value of source_port, or the default value if source_port is unset.

pub fn destination_port(&self) -> i32

Returns the value of destination_port, or the default value if destination_port is unset.