pub struct Packets {Show 37 fields
pub tombstone: Option<i32>,
pub status: Option<String>,
pub previous_status: Option<String>,
pub version: Option<i32>,
pub created_date: Option<String>,
pub created_time: Option<String>,
pub updated_date: Option<String>,
pub updated_time: Option<String>,
pub organization_id: Option<String>,
pub created_by: Option<String>,
pub updated_by: Option<String>,
pub deleted_by: Option<String>,
pub requested_by: Option<String>,
pub tags: Vec<String>,
pub id: String,
pub timestamp: String,
pub hypertable_timestamp: Option<String>,
pub interface_name: Option<String>,
pub device_id: Option<String>,
pub source_mac: Option<String>,
pub destination_mac: Option<String>,
pub ether_type: Option<String>,
pub protocol: Option<String>,
pub total_length: Option<i32>,
pub source_ip: Option<String>,
pub destination_ip: Option<String>,
pub source_port: Option<i32>,
pub destination_port: Option<i32>,
pub tcp_header_length: Option<i32>,
pub tcp_sequence_number: Option<i64>,
pub tcp_acknowledgment_number: Option<i64>,
pub tcp_data_offset: Option<i32>,
pub tcp_flags: Option<i32>,
pub tcp_window_size: Option<i32>,
pub tcp_urgent_pointer: Option<i32>,
pub icmp_type: Option<i32>,
pub icmp_code: Option<i32>,
}Expand description
Packets entity definition
Fields
tombstone: Option<i32>status: Option<String>previous_status: Option<String>version: Option<i32>created_date: Option<String>created_time: Option<String>updated_date: Option<String>updated_time: Option<String>organization_id: Option<String>created_by: Option<String>updated_by: Option<String>deleted_by: Option<String>requested_by: Option<String>id: Stringtimestamp: Stringhypertable_timestamp: Option<String>interface_name: Option<String>device_id: Option<String>source_mac: Option<String>destination_mac: Option<String>ether_type: Option<String>protocol: Option<String>total_length: Option<i32>source_ip: Option<String>destination_ip: Option<String>source_port: Option<i32>destination_port: Option<i32>tcp_header_length: Option<i32>tcp_sequence_number: Option<i64>tcp_acknowledgment_number: Option<i64>tcp_data_offset: Option<i32>tcp_flags: Option<i32>tcp_window_size: Option<i32>tcp_urgent_pointer: Option<i32>icmp_type: Option<i32>icmp_code: Option<i32>Implementations
Sourceimpl Packets
impl Packets
Sourcepub fn tombstone(&self) -> i32
pub fn tombstone(&self) -> i32
Returns the value of tombstone, or the default value if tombstone is unset.
Sourcepub fn status(&self) -> &str
pub fn status(&self) -> &str
Returns the value of status, or the default value if status is unset.
Sourcepub fn previous_status(&self) -> &str
pub fn previous_status(&self) -> &str
Returns the value of previous_status, or the default value if previous_status is unset.
Sourcepub fn version(&self) -> i32
pub fn version(&self) -> i32
Returns the value of version, or the default value if version is unset.
Sourcepub fn created_date(&self) -> &str
pub fn created_date(&self) -> &str
Returns the value of created_date, or the default value if created_date is unset.
Sourcepub fn created_time(&self) -> &str
pub fn created_time(&self) -> &str
Returns the value of created_time, or the default value if created_time is unset.
Sourcepub fn updated_date(&self) -> &str
pub fn updated_date(&self) -> &str
Returns the value of updated_date, or the default value if updated_date is unset.
Sourcepub fn updated_time(&self) -> &str
pub fn updated_time(&self) -> &str
Returns the value of updated_time, or the default value if updated_time is unset.
Sourcepub fn organization_id(&self) -> &str
pub fn organization_id(&self) -> &str
Returns the value of organization_id, or the default value if organization_id is unset.
Sourcepub fn created_by(&self) -> &str
pub fn created_by(&self) -> &str
Returns the value of created_by, or the default value if created_by is unset.
Sourcepub fn updated_by(&self) -> &str
pub fn updated_by(&self) -> &str
Returns the value of updated_by, or the default value if updated_by is unset.
Sourcepub fn deleted_by(&self) -> &str
pub fn deleted_by(&self) -> &str
Returns the value of deleted_by, or the default value if deleted_by is unset.
Sourcepub fn requested_by(&self) -> &str
pub fn requested_by(&self) -> &str
Returns the value of requested_by, or the default value if requested_by is unset.
Sourcepub fn hypertable_timestamp(&self) -> &str
pub fn hypertable_timestamp(&self) -> &str
Returns the value of hypertable_timestamp, or the default value if hypertable_timestamp is unset.
Sourcepub fn interface_name(&self) -> &str
pub fn interface_name(&self) -> &str
Returns the value of interface_name, or the default value if interface_name is unset.
Sourcepub fn device_id(&self) -> &str
pub fn device_id(&self) -> &str
Returns the value of device_id, or the default value if device_id is unset.
Sourcepub fn source_mac(&self) -> &str
pub fn source_mac(&self) -> &str
Returns the value of source_mac, or the default value if source_mac is unset.
Sourcepub fn destination_mac(&self) -> &str
pub fn destination_mac(&self) -> &str
Returns the value of destination_mac, or the default value if destination_mac is unset.
Sourcepub fn ether_type(&self) -> &str
pub fn ether_type(&self) -> &str
Returns the value of ether_type, or the default value if ether_type is unset.
Sourcepub fn protocol(&self) -> &str
pub fn protocol(&self) -> &str
Returns the value of protocol, or the default value if protocol is unset.
Sourcepub fn total_length(&self) -> i32
pub fn total_length(&self) -> i32
Returns the value of total_length, or the default value if total_length is unset.
Sourcepub fn source_ip(&self) -> &str
pub fn source_ip(&self) -> &str
Returns the value of source_ip, or the default value if source_ip is unset.
Sourcepub fn destination_ip(&self) -> &str
pub fn destination_ip(&self) -> &str
Returns the value of destination_ip, or the default value if destination_ip is unset.
Sourcepub fn source_port(&self) -> i32
pub fn source_port(&self) -> i32
Returns the value of source_port, or the default value if source_port is unset.
Sourcepub fn destination_port(&self) -> i32
pub fn destination_port(&self) -> i32
Returns the value of destination_port, or the default value if destination_port is unset.
Sourcepub fn tcp_header_length(&self) -> i32
pub fn tcp_header_length(&self) -> i32
Returns the value of tcp_header_length, or the default value if tcp_header_length is unset.
Sourcepub fn tcp_sequence_number(&self) -> i64
pub fn tcp_sequence_number(&self) -> i64
Returns the value of tcp_sequence_number, or the default value if tcp_sequence_number is unset.
Sourcepub fn tcp_acknowledgment_number(&self) -> i64
pub fn tcp_acknowledgment_number(&self) -> i64
Returns the value of tcp_acknowledgment_number, or the default value if tcp_acknowledgment_number is unset.
Sourcepub fn tcp_data_offset(&self) -> i32
pub fn tcp_data_offset(&self) -> i32
Returns the value of tcp_data_offset, or the default value if tcp_data_offset is unset.
Sourcepub fn tcp_flags(&self) -> i32
pub fn tcp_flags(&self) -> i32
Returns the value of tcp_flags, or the default value if tcp_flags is unset.
Sourcepub fn tcp_window_size(&self) -> i32
pub fn tcp_window_size(&self) -> i32
Returns the value of tcp_window_size, or the default value if tcp_window_size is unset.
Sourcepub fn tcp_urgent_pointer(&self) -> i32
pub fn tcp_urgent_pointer(&self) -> i32
Returns the value of tcp_urgent_pointer, or the default value if tcp_urgent_pointer is unset.