pub struct RegisterDeviceParams {
pub organization_id: String,
pub account_id: String,
pub account_secret: String,
pub is_new_user: bool,
pub is_invited: bool,
pub role_id: String,
pub account_organization_status: String,
pub account_organization_categories: Vec<String>,
pub device_categories: Vec<String>,
pub device_id: String,
}Fields
organization_id: Stringaccount_id: Stringaccount_secret: Stringis_new_user: boolis_invited: boolrole_id: Stringaccount_organization_status: Stringaccount_organization_categories: Vec<String>device_categories: Vec<String>device_id: StringTrait Implementations
Sourceimpl Clone for RegisterDeviceParams
impl Clone for RegisterDeviceParams
Sourcefn clone(&self) -> RegisterDeviceParams
fn clone(&self) -> RegisterDeviceParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegisterDeviceParams
impl Debug for RegisterDeviceParams
Sourceimpl Default for RegisterDeviceParams
impl Default for RegisterDeviceParams
Sourceimpl Message for RegisterDeviceParams
impl Message for RegisterDeviceParams
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RegisterDeviceParams
impl PartialEq for RegisterDeviceParams
impl StructuralPartialEq for RegisterDeviceParams